@@ -19,13 +19,16 @@
        USE H5E
        USE H5G
        USE H5I
+       USE H5L
        USE H5S
        USE H5D
        USE H5A
        USE H5T
+       USE H5O
        USE H5P
        USE H5FDMPIO
        USE H5R
        USE H5Z
+       USE H5_DBLE_INTERFACE
        USE H5LIB
     END MODULE HDF5
