@@ -39,6 +39,22 @@
 /* global variables */
 pio_time   *timer_g;            /* timer: global for stub functions     */
 
+/*
+ * Function:  sub_time
+ * Purpose:   Struct two time values, and return the difference, in microseconds
+ *
+ * 	      Note that the function assumes that a > b
+ * Programmer: Leon Arber, 1/27/06
+ */
+static double sub_time(struct timeval* a, struct timeval* b)
+{
+    return (((double)a->tv_sec +
+     ((double)a->tv_usec) / MICROSECOND) -
+	((double)b->tv_sec +
+	 ((double)b->tv_usec) / MICROSECOND));
+}
+
+
 /*
  * Function:    pio_time_new
  * Purpose:     Build us a brand, spankin', new performance time object.
@@ -120,21 +136,55 @@ set_time(pio_time *pt, timer_type t, int start_stop)
         if (pt->type == MPI_TIMER) {
             if (start_stop == START) {
                 pt->mpi_timer[t] = MPI_Wtime();
+
+		/* When we start the timer for HDF5_FINE_WRITE_FIXED_DIMS or HDF5_FINE_READ_FIXED_DIMS
+		 * we compute the time it took to only open the file */
+		if(t == HDF5_FINE_WRITE_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_WRITE_OPEN] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_GROSS_WRITE_FIXED_DIMS];
+		else if(t == HDF5_FINE_READ_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_READ_OPEN] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_GROSS_READ_FIXED_DIMS];
+
             } else {
                 pt->total_time[t] += MPI_Wtime() - pt->mpi_timer[t];
+		pt->mpi_timer[t] = MPI_Wtime();
+
+		/* When we stop the timer for HDF5_GROSS_WRITE_FIXED_DIMS or HDF5_GROSS_READ_FIXED_DIMS
+		 * we compute the time it took to close the file after the last read/write finished */
+		if(t == HDF5_GROSS_WRITE_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_WRITE_CLOSE] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_FINE_WRITE_FIXED_DIMS];
+		else if(t == HDF5_GROSS_READ_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_READ_CLOSE] += pt->mpi_timer[t] - pt->mpi_timer[HDF5_FINE_READ_FIXED_DIMS];
             }
         } else {
             if (start_stop == START) {
                 gettimeofday(&pt->sys_timer[t], NULL);
+
+		/* When we start the timer for HDF5_FINE_WRITE_FIXED_DIMS or HDF5_FINE_READ_FIXED_DIMS
+		 * we compute the time it took to only open the file */
+		if(t == HDF5_FINE_WRITE_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_WRITE_OPEN] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_GROSS_WRITE_FIXED_DIMS]));
+		else if(t == HDF5_FINE_READ_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_READ_OPEN] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_GROSS_READ_FIXED_DIMS]));
+
+
             } else {
                 struct timeval sys_t;
 
                 gettimeofday(&sys_t, NULL);
-                pt->total_time[t] +=
-                    ((double)sys_t.tv_sec +
+                pt->total_time[t] += sub_time(&sys_t, &(pt->sys_timer[t]));
+
+/*                    ((double)sys_t.tv_sec +
                                 ((double)sys_t.tv_usec) / MICROSECOND) -
                     ((double)pt->sys_timer[t].tv_sec +
-                            ((double)pt->sys_timer[t].tv_usec) / MICROSECOND);
+                            ((double)pt->sys_timer[t].tv_usec) / MICROSECOND);*/
+
+		/* When we stop the timer for HDF5_GROSS_WRITE_FIXED_DIMS or HDF5_GROSS_READ_FIXED_DIMS
+		 * we compute the time it took to close the file after the last read/write finished */
+		if(t == HDF5_GROSS_WRITE_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_WRITE_CLOSE] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_FINE_WRITE_FIXED_DIMS]));
+		else if(t == HDF5_GROSS_READ_FIXED_DIMS)
+		    pt->total_time[HDF5_FILE_READ_CLOSE] += sub_time(&(pt->sys_timer[t]), &(pt->sys_timer[HDF5_FINE_READ_FIXED_DIMS]));
+
             }
         }
 
@@ -203,3 +253,6 @@ get_time(pio_time *pt, timer_type t)
 }
 
 #endif /* H5_HAVE_PARALLEL */
+#ifdef STANDALONE
+#include "pio_standalone.c"
+#endif
