@@ -80,7 +80,6 @@ typedef struct H5A_fh_ud_cmp_t {
 
 /* v2 B-tree driver callbacks for 'creation order' index */
 static herr_t H5A_dense_btree2_corder_store(void *native, const void *udata);
-static herr_t H5A_dense_btree2_corder_retrieve(void *udata, const void *native);
 static herr_t H5A_dense_btree2_corder_compare(const void *rec1, const void *rec2);
 static herr_t H5A_dense_btree2_corder_encode(const H5F_t *f, uint8_t *raw,
     const void *native);
@@ -112,7 +111,6 @@ const H5B2_class_t H5A_BT2_NAME[1]={{  /* B-tree class information */
     H5B2_ATTR_DENSE_NAME_ID,                /* Type of B-tree */
     sizeof(H5A_dense_bt2_name_rec_t),  /* Size of native record */
     H5A_dense_btree2_name_store,       /* Record storage callback */
-    H5A_dense_btree2_name_retrieve,    /* Record retrieval callback */
     H5A_dense_btree2_name_compare,     /* Record comparison callback */
     H5A_dense_btree2_name_encode,      /* Record encoding callback */
     H5A_dense_btree2_name_decode,      /* Record decoding callback */
@@ -124,7 +122,6 @@ const H5B2_class_t H5A_BT2_CORDER[1]={{  /* B-tree class information */
     H5B2_ATTR_DENSE_CORDER_ID,                /* Type of B-tree */
     sizeof(H5A_dense_bt2_corder_rec_t),/* Size of native record */
     H5A_dense_btree2_corder_store,     /* Record storage callback */
-    H5A_dense_btree2_corder_retrieve,  /* Record retrieval callback */
     H5A_dense_btree2_corder_compare,   /* Record comparison callback */
     H5A_dense_btree2_corder_encode,    /* Record encoding callback */
     H5A_dense_btree2_corder_decode,    /* Record decoding callback */
@@ -227,30 +224,6 @@ H5A_dense_btree2_name_store(void *_nrecord, const void *_udata)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5A_dense_btree2_name_store() */
 
-
-/*-------------------------------------------------------------------------
- * Function:	H5A_dense_btree2_name_retrieve
- *
- * Purpose:	Retrieve native information from record for v2 B-tree
- *
- * Return:	Success:	non-negative
- *		Failure:	negative
- *
- * Programmer:	Quincey Koziol
- *              Monday, December  4, 2006
- *
- *-------------------------------------------------------------------------
- */
-static herr_t
-H5A_dense_btree2_name_retrieve(void *udata, const void *nrecord)
-{
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5A_dense_btree2_name_retrieve)
-
-    *(H5A_dense_bt2_name_rec_t *)udata = *(const H5A_dense_bt2_name_rec_t *)nrecord;
-
-    FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5A_dense_btree2_name_retrieve() */
-
 
 /*-------------------------------------------------------------------------
  * Function:	H5A_dense_btree2_name_compare
@@ -441,30 +414,6 @@ H5A_dense_btree2_corder_store(void *_nrecord, const void *_udata)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5A_dense_btree2_corder_store() */
 
-
-/*-------------------------------------------------------------------------
- * Function:	H5A_dense_btree2_corder_retrieve
- *
- * Purpose:	Retrieve native information from record for v2 B-tree
- *
- * Return:	Success:	non-negative
- *		Failure:	negative
- *
- * Programmer:	Quincey Koziol
- *              Tuesday, February  6, 2007
- *
- *-------------------------------------------------------------------------
- */
-static herr_t
-H5A_dense_btree2_corder_retrieve(void *udata, const void *nrecord)
-{
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5A_dense_btree2_corder_retrieve)
-
-    *(H5A_dense_bt2_corder_rec_t *)udata = *(const H5A_dense_bt2_corder_rec_t *)nrecord;
-
-    FUNC_LEAVE_NOAPI(SUCCEED)
-} /* H5A_dense_btree2_corder_retrieve() */
-
 
 /*-------------------------------------------------------------------------
  * Function:	H5A_dense_btree2_corder_compare
