@@ -1023,9 +1023,6 @@ H5A_attr_copy_file(const H5A_t *attr_src, H5F_t *file_dst, hbool_t *recompute_si
     if(H5A_set_version(file_dst, attr_dst) < 0)
         HGOTO_ERROR(H5E_ATTR, H5E_CANTSET, NULL, "unable to update attribute version")
 
-    /* Indicate that the fill values aren't to be written out */
-    attr_dst->shared->initialized = TRUE;
-
     /* Set return value */
     ret_value = attr_dst;
 
