@@ -37,6 +37,7 @@
 #include "H5Eprivate.h"		/* Error handling		  	*/
 #include "H5MMprivate.h"	/* Memory management			*/
 #include "H5Opkg.h"             /* Object headers			*/
+#include "H5Ppublic.h"		/* Property Lists			*/
 
 /****************/
 /* Local Macros */
@@ -127,7 +128,7 @@ H5O_assert(const H5O_t *oh)
         /* Version specific checks */
         if(oh->version > H5O_VERSION_1) {
             /* Make certain that the magic number is correct for each chunk */
-            HDassert(!HDmemcmp(oh->chunk[u].image, (u == 0 ? H5O_HDR_MAGIC : H5O_CHK_MAGIC), H5O_SIZEOF_MAGIC));
+            HDassert(!HDmemcmp(oh->chunk[u].image, (u == 0 ? H5O_HDR_MAGIC : H5O_CHK_MAGIC), H5_SIZEOF_MAGIC));
 
             /* Check for valid gap size */
             HDassert(oh->chunk[u].gap < (size_t)H5O_SIZEOF_MSGHDR_OH(oh));
@@ -269,12 +270,16 @@ done:
  *		matzke@llnl.gov
  *		Aug  6 1997
  *
+ * Modifications:
+ *   Feb. 2009: Vailin Choi
+ *	Fixed bug in the accumulation of chunk_total
+ *	Used the appropriate flag when printing creation order tracked/indexed
  *-------------------------------------------------------------------------
  */
 herr_t
 H5O_debug_real(H5F_t *f, hid_t dxpl_id, H5O_t *oh, haddr_t addr, FILE *stream, int indent, int fwidth)
 {
-    size_t	mesg_total = 0, chunk_total = 0;
+    size_t	mesg_total = 0, chunk_total = 0, gap_total = 0;
     unsigned	*sequence;
     unsigned	i;              /* Local index variable */
     herr_t	ret_value = SUCCEED;
@@ -310,10 +315,10 @@ H5O_debug_real(H5F_t *f, hid_t dxpl_id, H5O_t *oh, haddr_t addr, FILE *stream, i
         /* Display object's status flags */
 	HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
 		   "Attribute creation order tracked:",
-		   (oh->flags & H5P_CRT_ORDER_TRACKED) ? "Yes" : "No");
+		   (oh->flags & H5O_HDR_ATTR_CRT_ORDER_TRACKED) ? "Yes" : "No");
 	HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
 		   "Attribute creation order indexed:",
-		   (oh->flags & H5P_CRT_ORDER_INDEXED) ? "Yes" : "No");
+		   (oh->flags & H5O_HDR_ATTR_CRT_ORDER_INDEXED) ? "Yes" : "No");
 	HDfprintf(stream, "%*s%-*s %s\n", indent, "", fwidth,
 		   "Attribute storage phase change values:",
 		   (oh->flags & H5O_HDR_ATTR_STORE_PHASE_CHANGE) ? "Non-default" : "Default");
@@ -391,6 +396,7 @@ H5O_debug_real(H5F_t *f, hid_t dxpl_id, H5O_t *oh, haddr_t addr, FILE *stream, i
 
         /* Accumulate chunk's size to total */
 	chunk_total += chunk_size;
+	gap_total += oh->chunk[i].gap;
 
 	HDfprintf(stream, "%*s%-*s %Zu\n", indent + 3, "", MAX(0, fwidth - 3),
 		  "Size in bytes:",
@@ -402,7 +408,7 @@ H5O_debug_real(H5F_t *f, hid_t dxpl_id, H5O_t *oh, haddr_t addr, FILE *stream, i
     } /* end for */
 
     /* debug each message */
-    if(NULL == (sequence = H5MM_calloc(NELMTS(H5O_msg_class_g) * sizeof(unsigned))))
+    if(NULL == (sequence = (unsigned *)H5MM_calloc(NELMTS(H5O_msg_class_g) * sizeof(unsigned))))
 	HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
     for(i = 0, mesg_total = 0; i < oh->nmesgs; i++) {
         const H5O_msg_class_t  *debug_type;              /* Type of message to use for callbacks */
@@ -411,6 +417,10 @@ H5O_debug_real(H5F_t *f, hid_t dxpl_id, H5O_t *oh, haddr_t addr, FILE *stream, i
         /* Accumulate message's size to total */
 	mesg_total += H5O_SIZEOF_MSGHDR_OH(oh) + oh->mesg[i].raw_size;
 
+	/* For version 2 object header, add size of "OCHK" for continuation chunk */
+	if (oh->mesg[i].type->id == H5O_CONT_ID)
+	    mesg_total += H5O_SIZEOF_CHKHDR_OH(oh);
+
 	HDfprintf(stream, "%*sMessage %d...\n", indent, "", i);
 
 	/* check for bad message id */
@@ -488,7 +498,7 @@ H5O_debug_real(H5F_t *f, hid_t dxpl_id, H5O_t *oh, haddr_t addr, FILE *stream, i
 	/* decode the message */
 	debug_type = oh->mesg[i].type;
 	if(NULL == oh->mesg[i].native && debug_type->decode)
-            H5O_LOAD_NATIVE(f, dxpl_id, oh, &oh->mesg[i], FAIL)
+            H5O_LOAD_NATIVE(f, dxpl_id, H5O_DECODEIO_NOCHANGE, oh, &oh->mesg[i], FAIL)
 
 	/* print the message */
 	HDfprintf(stream, "%*s%-*s\n", indent + 3, "", MAX(0, fwidth - 3),
@@ -498,9 +508,9 @@ H5O_debug_real(H5F_t *f, hid_t dxpl_id, H5O_t *oh, haddr_t addr, FILE *stream, i
 	else
 	    HDfprintf(stream, "%*s<No info for this message>\n", indent + 6, "");
     } /* end for */
-    sequence = H5MM_xfree(sequence);
+    sequence = (unsigned *)H5MM_xfree(sequence);
 
-    if(mesg_total != chunk_total)
+    if((mesg_total + gap_total) != chunk_total)
 	HDfprintf(stream, "*** TOTAL SIZE DOES NOT MATCH ALLOCATED SIZE!\n");
 
 done:
@@ -536,7 +546,7 @@ H5O_debug(H5F_t *f, hid_t dxpl_id, haddr_t addr, FILE *stream, int indent, int f
     HDassert(indent >= 0);
     HDassert(fwidth >= 0);
 
-    if(NULL == (oh = H5AC_protect(f, dxpl_id, H5AC_OHDR, addr, NULL, NULL, H5AC_READ)))
+    if(NULL == (oh = (H5O_t *)H5AC_protect(f, dxpl_id, H5AC_OHDR, addr, NULL, NULL, H5AC_READ)))
 	HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to load object header")
 
     /* debug */
