@@ -113,7 +113,7 @@ TOOLTEST()
            rm -f output.out
         fi
     fi
-   
+    
     if [ $runh5diff != no ]; then
      H5DIFFTEST $inputfile $outputfile $7 $9
     fi
@@ -167,13 +167,8 @@ TOOLTEST_FAIL()
 H5DIFFTEST() 
 {
     VERIFY  $@
-    if [ "`uname -s`" = "TFLOPS O/S" ]; then
-        $RUNSERIAL $H5DIFF_BIN -q $@ 
-    else
-        $RUNSERIAL $H5DIFF_BIN -q "$@" 
-    fi
+    $RUNSERIAL $H5DIFF_BIN -q "$@" 
     RET=$?
-
     if [ $RET != 0 ] ; then
          echo "*FAILED*"
          nerrors="`expr $nerrors + 1`"
@@ -187,11 +182,7 @@ H5DIFFTEST()
 H5DIFFTEST_FAIL() 
 {
     VERIFY  $@
-    if [ "`uname -s`" = "TFLOPS O/S" ]; then
-        $RUNSERIAL $H5DIFF_BIN -q $@ 
-    else
-        $RUNSERIAL $H5DIFF_BIN -q "$@" 
-    fi
+    $RUNSERIAL $H5DIFF_BIN -q "$@" 
     RET=$?
 
     if [ $RET != 1 ] ; then
